# pcsg - a constructive solid geometry library for Python

Constructive geometry is a technique used for modeling shapes and solids.
The ***pcsg*** library can be used to create 3D printable solid objects, images and animations utilizing external programs like [OpenScad](https://www.openscad.org/) and [POV-Ray](http://www.povray.org/).
Introducing a common description format eleminates the need for learning different scripting languages and rewriting your code.

**NOTE**: The current implementation of pcsg is a prototype. It’s assumed that the API will change in future releases.

## Getting started
* Read the [documentation](http://www.dessecker.net/projects/pcsg/latest/index.html).
* Install from [PyPI](https://pypi.org/project/pcsg).
* Checkout the [sources](https://github.com/WhiteSheet/pcsg).
